pub struct Config {
pub network: String,
pub nodes: Vec<SocketAddr>,
pub incoming_source: IncomingSource,
pub logger: LoggerConfig,
}Expand description
This struct contains configuration options for the BTC Adapter.
Fields
network: StringThe type of Bitcoin network we plan to communicate to (e.g. “mainnet”, “testnet”, “regtest”, etc.).
nodes: Vec<SocketAddr>Addresses of nodes to connect to (in case discovery from seeds is not possible/sufficient)
incoming_source: IncomingSourceSpecifies which unix domain socket should be used for serving incoming requests.
logger: LoggerConfigImplementations
Sourceimpl Config
impl Config
pub fn new( nodes: Vec<SocketAddr>, uds_path: PathBuf, log_level: BitcoinAdapterLogLevel, ) -> Config
pub fn get_socket_path(&self) -> Option<PathBuf>