pub struct CanisterDeclarationsConfig {
pub output: Option<PathBuf>,
pub bindings: Option<Vec<String>>,
pub env_override: Option<String>,
pub node_compatibility: bool,
}Expand description
Declarations Configuration
Configurations about which canister interface declarations to generate, and where to generate them.
Fields
output: Option<PathBuf>Declaration Output Directory
Directory to place declarations for that canister. Default is ‘src/declarations/<canister_name>’.
bindings: Option<Vec<String>>Languages to generate
A list of languages to generate type declarations. Supported options are ‘js’, ‘ts’, ‘did’, ‘mo’. Default is [‘js’, ‘ts’, ‘did’].
env_override: Option<String>Canister ID ENV Override
A string that will replace process.env.CANISTER_ID_{canister_name_uppercase} in the ‘src/dfx/assets/language_bindings/canister.js’ template.
node_compatibility: boolNode compatibility flag
Flag to pre-populate generated declarations with better defaults for various types of projects Default is false