pub struct CanisterMetadataSection {
pub name: String,
pub visibility: MetadataVisibility,
pub networks: Option<BTreeSet<String>>,
pub path: Option<PathBuf>,
pub content: Option<String>,
}Expand description
Canister Metadata Configuration
Configures a custom metadata section for the canister wasm. dfx uses the first definition of a given name matching the current network, ignoring any of the same name that follow.
Fields
name: StringName
The name of the wasm section
visibility: MetadataVisibilityVisibility
networks: Option<BTreeSet<String>>Networks
Networks this section applies to. If this field is absent, then it applies to all networks. An empty array means this element will not apply to any network.
path: Option<PathBuf>Path
Path to file containing section contents.
Conflicts with content.
For sections with name=candid:service, this field is optional, and if not specified, dfx will use
the canister’s candid definition.
If specified for a Motoko canister, the service defined in the specified path must be a valid subtype of the canister’s
actual candid service definition.
content: Option<String>Content
Content of this metadata section.
Conflicts with path.
Implementations
Sourceimpl CanisterMetadataSection
impl CanisterMetadataSection
pub fn applies_to_network(&self, network: &str) -> bool