pub struct ConfigCanistersCanisterRemote {
pub candid: Option<PathBuf>,
pub id: BTreeMap<String, Principal>,
}Expand description
Remote Canister Configuration
This field allows canisters to be marked ‘remote’ for certain networks. On networks where this canister contains a remote ID, the canister is not deployed. Instead it is assumed to exist already under control of a different project.
Fields
candid: Option<PathBuf>Remote Candid File
On networks where this canister is marked ‘remote’, this candid file is used instead of the one declared in the canister settings.
id: BTreeMap<String, Principal>Network to Remote ID Mapping
This field contains mappings from network names to remote canister IDs (Principals). For all networks listed here, this canister is considered ‘remote’.