pub struct ConfigDefaultsBootstrap {
pub ip: IpAddr,
pub port: u16,
pub timeout: u64,
}Expand description
Bootstrap Server Configuration
The bootstrap command has been removed. All of these fields are ignored.
Fields
ip: IpAddrSpecifies the IP address that the bootstrap server listens on. Defaults to 127.0.0.1.
port: u16Specifies the port number that the bootstrap server listens on. Defaults to 8081.
timeout: u64Specifies the maximum number of seconds that the bootstrap server will wait for upstream requests to complete. Defaults to 30.