pub struct ConfigDefaultsReplica {
pub port: Option<u16>,
pub subnet_type: Option<ReplicaSubnetType>,
pub log_level: Option<ReplicaLogLevel>,
}Expand description
Local Replica Configuration
Fields
port: Option<u16>Port the replica listens on.
subnet_type: Option<ReplicaSubnetType>Subnet Type
Determines the subnet type the replica will run as. Affects things like cycles accounting, message size limits, cycle limits. Defaults to ‘application’.
log_level: Option<ReplicaLogLevel>Run replica with the provided log level. Default is ‘error’. Debug prints still get displayed