pub struct ConfigLocalProvider {
pub bind: Option<String>,
pub type: NetworkType,
pub bitcoin: Option<ConfigDefaultsBitcoin>,
pub bootstrap: Option<ConfigDefaultsBootstrap>,
pub canister_http: Option<ConfigDefaultsCanisterHttp>,
pub replica: Option<ConfigDefaultsReplica>,
pub playground: Option<PlaygroundConfig>,
pub proxy: Option<ConfigDefaultsProxy>,
}Expand description
Local Replica Configuration
Fields
bind: Option<String>Bind address for the webserver. For the shared local network, the default is 127.0.0.1:4943. For project-specific local networks, the default is 127.0.0.1:8000.
type: NetworkTypePersistence type of this network.
bitcoin: Option<ConfigDefaultsBitcoin>bootstrap: Option<ConfigDefaultsBootstrap>canister_http: Option<ConfigDefaultsCanisterHttp>replica: Option<ConfigDefaultsReplica>playground: Option<PlaygroundConfig>proxy: Option<ConfigDefaultsProxy>Trait Implementations
Sourceimpl Clone for ConfigLocalProvider
impl Clone for ConfigLocalProvider
Sourcefn clone(&self) -> ConfigLocalProvider
fn clone(&self) -> ConfigLocalProvider
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigLocalProvider
impl Debug for ConfigLocalProvider
Sourceimpl Default for ConfigLocalProvider
impl Default for ConfigLocalProvider
Sourcefn default() -> ConfigLocalProvider
fn default() -> ConfigLocalProvider
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ConfigLocalProvider
impl<'de> Deserialize<'de> for ConfigLocalProvider
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigLocalProvider
impl JsonSchema for ConfigLocalProvider
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigLocalProvider
impl PartialEq for ConfigLocalProvider
Sourceimpl Serialize for ConfigLocalProvider
impl Serialize for ConfigLocalProvider
impl Eq for ConfigLocalProvider
impl StructuralPartialEq for ConfigLocalProvider