pub struct ConfigNetworkProvider {
pub providers: Vec<String>,
pub type: NetworkType,
pub playground: Option<PlaygroundConfig>,
}Expand description
Custom Network Configuration
Fields
providers: Vec<String>The URL(s) this network can be reached at.
type: NetworkTypePersistence type of this network.
playground: Option<PlaygroundConfig>Trait Implementations
Sourceimpl Clone for ConfigNetworkProvider
impl Clone for ConfigNetworkProvider
Sourcefn clone(&self) -> ConfigNetworkProvider
fn clone(&self) -> ConfigNetworkProvider
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigNetworkProvider
impl Debug for ConfigNetworkProvider
Sourceimpl Default for ConfigNetworkProvider
impl Default for ConfigNetworkProvider
Sourcefn default() -> ConfigNetworkProvider
fn default() -> ConfigNetworkProvider
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ConfigNetworkProvider
impl<'de> Deserialize<'de> for ConfigNetworkProvider
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ConfigNetworkProvider
impl JsonSchema for ConfigNetworkProvider
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(gen: &mut SchemaGenerator) -> Schema
fn json_schema(gen: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConfigNetworkProvider
impl PartialEq for ConfigNetworkProvider
Sourceimpl Serialize for ConfigNetworkProvider
impl Serialize for ConfigNetworkProvider
impl Eq for ConfigNetworkProvider
impl StructuralPartialEq for ConfigNetworkProvider