pub struct Pullable {
pub wasm_url: String,
pub wasm_hash: Option<String>,
pub wasm_hash_url: Option<String>,
pub dependencies: Vec<Principal>,
pub init_guide: String,
pub init_arg: Option<String>,
}Fields
wasm_url: Stringwasm_url
The Url to download canister wasm.
wasm_hash: Option<String>wasm_hash
SHA256 hash of the wasm module located at wasm_url.
Only define this if the on-chain canister wasm is expected not to match the wasm at wasm_url.
The hash can also be specified via a URL using the wasm_hash_url field.
If both are defined, the wasm_hash_url field will be ignored.
wasm_hash_url: Option<String>wasm_hash_url
Specify the SHA256 hash of the wasm module via this URL.
Only define this if the on-chain canister wasm is expected not to match the wasm at wasm_url.
The hash can also be specified directly using the wasm_hash field.
If both are defined, the wasm_hash_url field will be ignored.
dependencies: Vec<Principal>dependencies
Canister IDs (Principal) of direct dependencies.
init_guide: Stringinit_guide
A message to guide consumers how to initialize the canister.
init_arg: Option<String>init_arg
A default initialization argument for the canister that consumers can use.