pub struct ToolConfigInterface {
pub telemetry: TelemetryState,
}Fields
telemetry: TelemetryStateTrait Implementations
Sourceimpl<'de> Deserialize<'de> for ToolConfigInterface
impl<'de> Deserialize<'de> for ToolConfigInterface
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ToolConfigInterface
impl JsonSchema for ToolConfigInterface
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ToolConfigInterface
impl RefUnwindSafe for ToolConfigInterface
impl Send for ToolConfigInterface
impl Sync for ToolConfigInterface
impl Unpin for ToolConfigInterface
impl UnsafeUnpin for ToolConfigInterface
impl UnwindSafe for ToolConfigInterface