pub struct ProjectTemplate {
pub name: ProjectTemplateName,
pub display: String,
pub resource_location: ResourceLocation,
pub category: ProjectTemplateCategory,
pub requirements: Vec<ProjectTemplateName>,
pub post_create: Vec<String>,
pub post_create_spinner_message: Option<String>,
pub post_create_failure_warning: Option<String>,
pub sort_order: u32,
}Fields
name: ProjectTemplateNameThe name of the template as specified on the command line,
for example --type rust
display: StringThe name used for display and sorting
resource_location: ResourceLocationHow to obtain the template’s files
category: ProjectTemplateCategoryUsed to determine which CLI group (--type, --backend, --frontend)
as well as for interactive selection
requirements: Vec<ProjectTemplateName>Other project templates to patch in alongside this one
post_create: Vec<String>Run a command after adding the canister to dfx.json
post_create_spinner_message: Option<String>If set, display a spinner while this command runs
post_create_failure_warning: Option<String>If the post-create command fails, display this warning but don’t fail
sort_order: u32The sort order is fixed rather than settable in properties: For backend:
- motoko=0
- rust=1
- everything else=2 (and then by display name)
For frontend:
- SvelteKit=0
- React=1
- Vue=2
- Vanilla JS=3
- No JS Template=4
- everything else=5 (and then by display name)
For extras:
- Internet Identity=0
- Bitcoin=1
- everything else=2 (and then by display name)
- Frontend Tests