pub struct Identity {
pub insecure: bool,
/* private fields */
}Fields
insecure: boolWhether this identity is stored in unencrypted form. False for identities that are not stored at all.
Implementations
Sourceimpl Identity
impl Identity
pub fn anonymous() -> Self
pub fn identity_type(&self) -> IdentityType
Sourcepub fn display_linked_wallets(
logger: &Logger,
wallet_config: &Path,
) -> Result<(), WalletConfigError>
pub fn display_linked_wallets( logger: &Logger, wallet_config: &Path, ) -> Result<(), WalletConfigError>
Logs all wallets that are configured in a WalletGlobalConfig.
pub fn load_wallet_config( path: &Path, ) -> Result<WalletGlobalConfig, WalletConfigError>
pub fn save_wallet_config( path: &Path, config: &WalletGlobalConfig, ) -> Result<(), SaveWalletConfigError>
pub fn map_wallets_to_renamed_identity( project_temp_dir: Option<PathBuf>, original_identity: &str, renamed_identity: &str, ) -> Result<(), MapWalletsToRenamedIdentityError>