Module directory

Module directory 

Functions

ensure_cohesive_network_directory
A cohesive network directory is one in which the directory in question contains a file network-id, which contains the same contents as the network-id file in the network data directory. In this way, after dfx start --clean, we can later clean up data in project directories.