pub struct HttpHandlerConfig {
pub port: Option<u16>,
pub write_port_to: Option<PathBuf>,
}Fields
port: Option<u16>Instructs the HTTP handler to use the specified port
write_port_to: Option<PathBuf>Instructs the HTTP handler to bind to any open port and report the port to the specified file. The port is written in its textual representation, no newline at the end.
Implementations