Functions
- ensure_
cohesive_ network_ directory - A cohesive network directory is one in which the directory in question contains
a file
network-id, which contains the same contents as thenetwork-idfile in the network data directory. In this way, afterdfx start --clean, we can later clean up data in project directories.